@@ -44,7 +44,7 @@ use Stow::Util qw(set_debug_level debug error set_test_mode
                   join_paths restore_cwd canon_path parent);
 
 our $ProgramName = 'stow';
-our $VERSION = '2.1.3';
+our $VERSION = '2.2.0';
 
 our $LOCAL_IGNORE_FILE  = '.stow-local-ignore';
 our $GLOBAL_IGNORE_FILE = '.stow-global-ignore';
@@ -54,16 +54,17 @@ our @default_global_ignore_regexps =
 
 # These are the default options for each Stow instance.
 our %DEFAULT_OPTIONS = (
-    conflicts  => 0,
-    simulate   => 0,
-    verbose    => 0,
-    paranoid   => 0,
-    compat     => 0,
-    test_mode  => 0,
-    adopt      => 0,
-    ignore     => [],
-    override   => [],
-    defer      => [],
+    conflicts    => 0,
+    simulate     => 0,
+    verbose      => 0,
+    paranoid     => 0,
+    compat       => 0,
+    test_mode    => 0,
+    adopt        => 0,
+    'no-folding' => 0,
+    ignore       => [],
+    override     => [],
+    defer        => [],
 );
 
 =head1 CONSTRUCTORS
@@ -82,6 +83,8 @@ our %DEFAULT_OPTIONS = (
 
 =head3 Non-mandatory options
 
+See the documentation for the F<stow> CLI front-end for information on these.
+
 =over 4
 
 =item * conflicts
@@ -92,6 +95,14 @@ our %DEFAULT_OPTIONS = (
 
 =item * paranoid
 
+=item * compat
+
+=item * test_mode
+
+=item * adopt
+
+=item * no-folding
+
 =item * ignore
 
 =item * override
@@ -142,6 +153,7 @@ sub get_verbosity {
 
     return $self->{verbose} unless $self->{test_mode};
 
+    return 0 unless exists $ENV{TEST_VERBOSE};
     return 0 unless length $ENV{TEST_VERBOSE};
 
     # Convert TEST_VERBOSE=y into numeric value
@@ -239,8 +251,9 @@ sub plan_unstow {
 
     $self->within_target_do(sub {
         for my $package (@packages) {
-            if (not -d join_paths($self->{stow_path}, $package)) {
-                error("The stow directory $self->{dir} does not contain package $package");
+            my $path = join_paths($self->{stow_path}, $package);
+            if (not -d $path) {
+                error("The stow directory $self->{stow_path} does not contain package $package");
             }
             debug(2, "Planning unstow of package $package...");
             if ($self->{compat}) {
@@ -277,15 +290,16 @@ sub plan_stow {
 
     $self->within_target_do(sub {
         for my $package (@packages) {
-            if (not -d join_paths($self->{stow_path}, $package)) {
-                error("The stow directory $self->{dir} does not contain package $package");
+            my $path = join_paths($self->{stow_path}, $package);
+            if (not -d $path) {
+                error("The stow directory $self->{stow_path} does not contain package $package");
             }
             debug(2, "Planning stow of package $package...");
             $self->stow_contents(
                 $self->{stow_path},
                 $package,
                 '.',
-                join_paths($self->{stow_path}, $package), # source from target
+                $path, # source from target
             );
             debug(2, "Planning stow of package $package... done");
             $self->{action_count}++;
@@ -506,6 +520,15 @@ sub stow_node {
             }
         }
     }
+    elsif ($self->{'no-folding'} && -d $path) {
+        $self->do_mkdir($target);
+        $self->stow_contents(
+            $self->{stow_path},
+            $package,
+            $target,
+            join_paths('..', $source),
+        );
+    }
     else {
         $self->do_link($source, $target);
     }
@@ -983,6 +1006,10 @@ sub foldable {
     my ($target) = @_;
 
     debug(3, "--- Is $target foldable?");
+    if ($self->{'no-folding'}) {
+        debug(3, "--- no because --no-folding enabled");
+        return '';
+    }
 
     opendir my $DIR, $target
         or error(qq{Cannot read directory "$target" ($!)\n});
@@ -1391,7 +1418,6 @@ sub process_tasks {
     $self->{tasks} = [ grep { $_->{action} ne 'skip' } @{ $self->{tasks} } ];
 
     if (not @{ $self->{tasks} }) {
-        warn "There are no outstanding operations to perform.\n";
         return;
     }
 
